@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2019 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2020 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -22,7 +22,7 @@
 import typing
 import attr
 
-from qutebrowser.utils import jinja, usertypes, log
+from qutebrowser.utils import usertypes, log
 
 
 class Error(Exception):
@@ -155,6 +155,7 @@ class ConfigFileErrors(Error):
 
     def to_html(self) -> str:
         """Get the error texts as a HTML snippet."""
+        from qutebrowser.utils import jinja  # circular import
         template = jinja.environment.from_string("""
         Errors occurred while reading {{ basename }}:
 
