@@ -56,12 +56,12 @@ import typing
 import attr
 import yaml
 from PyQt5.QtCore import QUrl, Qt
-from PyQt5.QtGui import QColor, QFont
-from PyQt5.QtWidgets import QTabWidget, QTabBar
+from PyQt5.QtGui import QColor, QFont, QFontDatabase
+from PyQt5.QtWidgets import QTabWidget, QTabBar, QApplication
 from PyQt5.QtNetwork import QNetworkProxy
 
 from qutebrowser.misc import objects, debugcachestats
-from qutebrowser.config import configexc
+from qutebrowser.config import configexc, configutils
 from qutebrowser.utils import (standarddir, utils, qtutils, urlutils, urlmatch,
                                usertypes)
 from qutebrowser.keyinput import keyutils
@@ -364,12 +364,13 @@ class String(BaseType):
         minlen: Minimum length (inclusive).
         maxlen: Maximum length (inclusive).
         forbidden: Forbidden chars in the string.
+        regex: A regex used to validate the string.
         completions: completions to be used, or None
     """
 
     def __init__(self, *, minlen: int = None, maxlen: int = None,
-                 forbidden: str = None, encoding: str = None,
-                 none_ok: bool = False,
+                 forbidden: str = None, regex: str = None,
+                 encoding: str = None, none_ok: bool = False,
                  completions: _Completions = None,
                  valid_values: ValidValues = None) -> None:
         super().__init__(none_ok)
@@ -387,6 +388,7 @@ class String(BaseType):
         self.forbidden = forbidden
         self._completions = completions
         self.encoding = encoding
+        self.regex = regex
 
     def _validate_encoding(self, value: str) -> None:
         """Check if the given value fits into the configured encoding.
@@ -426,6 +428,9 @@ class String(BaseType):
         if self.maxlen is not None and len(value) > self.maxlen:
             raise configexc.ValidationError(value, "must be at most {} chars "
                                             "long!".format(self.maxlen))
+        if self.regex is not None and not re.fullmatch(self.regex, value):
+            raise configexc.ValidationError(value, "does not match {}"
+                                            .format(self.regex))
 
         return value
 
@@ -440,7 +445,7 @@ class String(BaseType):
                               valid_values=self.valid_values,
                               minlen=self.minlen,
                               maxlen=self.maxlen, forbidden=self.forbidden,
-                              completions=self._completions,
+                              regex=self.regex, completions=self._completions,
                               encoding=self.encoding)
 
 
@@ -1151,7 +1156,8 @@ class Font(BaseType):
     """
 
     # Gets set when the config is initialized.
-    monospace_fonts = None  # type: str
+    default_family = None  # type: str
+    default_size = None  # type: str
     font_regex = re.compile(r"""
         (
             (
@@ -1163,11 +1169,66 @@ class Font(BaseType):
                     (?P<namedweight>normal|bold)
                 ) |
                 # size (<float>pt | <int>px)
-                (?P<size>[0-9]+((\.[0-9]+)?[pP][tT]|[pP][xX]))
+                (?P<size>[0-9]+((\.[0-9]+)?[pP][tT]|[pP][xX])|default_size)
             )\           # size/weight/style are space-separated
         )*               # 0-inf size/weight/style tags
         (?P<family>.+)  # mandatory font family""", re.VERBOSE)
 
+    @classmethod
+    def set_defaults(cls, default_family: typing.List[str],
+                     default_size: str) -> None:
+        """Make sure default_family/default_size are available.
+
+        If the given family value (fonts.default_family in the config) is
+        unset, a system-specific default monospace font is used.
+
+        Note that (at least) three ways of getting the default monospace font
+        exist:
+
+        1) f = QFont()
+           f.setStyleHint(QFont.Monospace)
+           print(f.defaultFamily())
+
+        2) f = QFont()
+           f.setStyleHint(QFont.TypeWriter)
+           print(f.defaultFamily())
+
+        3) f = QFontDatabase.systemFont(QFontDatabase.FixedFont)
+           print(f.family())
+
+        They yield different results depending on the OS:
+
+                   QFont.Monospace  | QFont.TypeWriter    | QFontDatabase
+                   ------------------------------------------------------
+        Windows:   Courier New      | Courier New         | Courier New
+        Linux:     DejaVu Sans Mono | DejaVu Sans Mono    | monospace
+        macOS:     Menlo            | American Typewriter | Monaco
+
+        Test script: https://p.cmpl.cc/d4dfe573
+
+        On Linux, it seems like both actually resolve to the same font.
+
+        On macOS, "American Typewriter" looks like it indeed tries to imitate a
+        typewriter, so it's not really a suitable UI font.
+
+        Looking at those Wikipedia articles:
+
+        https://en.wikipedia.org/wiki/Monaco_(typeface)
+        https://en.wikipedia.org/wiki/Menlo_(typeface)
+
+        the "right" choice isn't really obvious. Thus, let's go for the
+        QFontDatabase approach here, since it's by far the simplest one.
+        """
+        if default_family:
+            families = configutils.FontFamilies(default_family)
+        else:
+            assert QApplication.instance() is not None
+            font = QFontDatabase.systemFont(QFontDatabase.FixedFont)
+            families = configutils.FontFamilies([font.family()])
+
+        cls.default_family = families.to_str(quote=True)
+        cls.default_size = default_size
+
     def to_py(self, value: _StrUnset) -> _StrUnsetNone:
         self._basic_py_validation(value, str)
         if isinstance(value, usertypes.Unset):
@@ -1180,8 +1241,13 @@ class Font(BaseType):
             # as family.
             raise configexc.ValidationError(value, "must be a valid font")
 
-        if value.endswith(' monospace') and self.monospace_fonts is not None:
-            return value.replace('monospace', self.monospace_fonts)
+        if (value.endswith(' default_family') and
+                self.default_family is not None):
+            value = value.replace('default_family', self.default_family)
+
+        if 'default_size ' in value and self.default_size is not None:
+            value = value.replace('default_size', self.default_size)
+
         return value
 
 
@@ -1215,21 +1281,11 @@ class QtFont(Font):
 
     __doc__ = Font.__doc__  # for src2asciidoc.py
 
-    def _parse_families(self, family_str: str) -> typing.List[str]:
-        if family_str == 'monospace' and self.monospace_fonts is not None:
-            family_str = self.monospace_fonts
+    def _parse_families(self, family_str: str) -> configutils.FontFamilies:
+        if family_str == 'default_family' and self.default_family is not None:
+            family_str = self.default_family
 
-        families = []
-        for part in family_str.split(','):
-            part = part.strip()
-            # The Qt CSS parser handles " and ' before passing the string to
-            # QFont.setFamily.
-            if ((part.startswith("'") and part.endswith("'")) or
-                    (part.startswith('"') and part.endswith('"'))):
-                part = part[1:-1]
-            families.append(part)
-
-        return families
+        return configutils.FontFamilies.from_str(family_str)
 
     def to_py(self, value: _StrUnset) -> typing.Union[usertypes.Unset,
                                                       None, QFont]:
@@ -1253,7 +1309,7 @@ class QtFont(Font):
         weight = match.group('weight')
         namedweight = match.group('namedweight')
         size = match.group('size')
-        family = match.group('family')
+        family_str = match.group('family')
 
         style_map = {
             'normal': QFont.StyleNormal,
@@ -1274,6 +1330,9 @@ class QtFont(Font):
             font.setWeight(min(int(weight) // 8, 99))
 
         if size:
+            if size == 'default_size':
+                size = self.default_size
+
             if size.lower().endswith('pt'):
                 font.setPointSizeF(float(size[:-2]))
             elif size.lower().endswith('px'):
@@ -1284,13 +1343,13 @@ class QtFont(Font):
                 raise ValueError("Unexpected size unit in {!r}!".format(
                     size))  # pragma: no cover
 
-        families = self._parse_families(family)
+        families = self._parse_families(family_str)
         if hasattr(font, 'setFamilies'):
             # Added in Qt 5.13
-            font.setFamily(families[0])
-            font.setFamilies(families)
+            font.setFamily(families.family)  # type: ignore
+            font.setFamilies(list(families))
         else:  # pragma: no cover
-            font.setFamily(', '.join(families))
+            font.setFamily(families.to_str(quote=False))
 
         return font
 
